@@ -1137,7 +1137,7 @@ def elaborate_pulsed_fraction(ee_pulsed, dee_pulsed, pulsed_frac, dpulsed_frac,
 
 def fit_pulsed_frac(en, den, pf, dpf, stem=None, degree_pol=4, n_gauss=0, center=[],
                     sigma=[], amplitude=[],
-                    plot_final=True, print_results=True, y_lim=[0,1], x_lim=[3,70]):
+                    plot_final=True, print_results=True, y_lim=[0,1.1], x_lim=[3,70]):
     '''
     this function will fit an input energy range of the pulse profile.
     the fitting function will be a simple polynomial + gaussian
@@ -1215,6 +1215,7 @@ def fit_pulsed_frac(en, den, pf, dpf, stem=None, degree_pol=4, n_gauss=0, center
         axes[1].errorbar(en, pf, xerr=den, yerr=dpf, fmt='.', color=col[0])
         for N in range(1, n_gauss+1):
             axes[1].plot(en, comps['g%d_' % N], '--', label='Gaussian %d' % N, color=col[3])
+            axes[1].axvline(center[N - 1][0], 0, 1, linestyle='--', color='cyan')
         axes[1].plot(en, comps['poly_'], '--', label='Polynomial component', color=col[4])
         axes[1].legend(loc='upper left')
         axes[1].set_xlabel('E [keV]')
